@@ -28,7 +28,7 @@ setMethod("TSconnect",   signature(drv="PostgreSQLDriver", dbname="character"),
  	       hasPanels  =dbExistsTable(con, "panels")) 
 	})
 
-setMethod("TSput",   signature(x="ANY", serIDs="character", con="PostgreSQLConnection"),
+setMethod("TSput",   signature(x="ANY", serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(x, serIDs, con=getOption("TSconnection"), Table=NULL, 
        TSdescription.=TSdescription(x), TSdoc.=TSdoc(x), TSlabel.=TSlabel(x),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
@@ -36,7 +36,7 @@ setMethod("TSput",   signature(x="ANY", serIDs="character", con="PostgreSQLConne
    TSdescription.=TSdescription., TSdoc.=TSdoc., TSlabel.=TSlabel., 
    vintage=vintage, panel=panel) )
 
-setMethod("TSget",   signature(serIDs="character", con="PostgreSQLConnection"),
+setMethod("TSget",   signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"), 
        TSrepresentation=getOption("TSrepresentation"),
        tf=NULL, start=tfstart(tf), end=tfend(tf),
@@ -47,25 +47,25 @@ setMethod("TSget",   signature(serIDs="character", con="PostgreSQLConnection"),
        names=names, TSdescription=TSdescription, TSdoc=TSdoc, TSlabel=TSlabel,
        vintage=vintage, panel=panel) )
 
-setMethod("TSdates",    signature(serIDs="character", con="PostgreSQLConnection"),
+setMethod("TSdates",    signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
        vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
       TSdbi:::TSdatesSQL(serIDs, con, vintage=vintage, panel=panel) )
 
 
-setMethod("TSdescription",   signature(x="character", con="PostgreSQLConnection"),
+setMethod("TSdescription",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
         TSdbi:::TSdescriptionSQL(x=x, con=con) )
 
-setMethod("TSdoc",   signature(x="character", con="PostgreSQLConnection"),
+setMethod("TSdoc",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
         TSdbi:::TSdocSQL(x=x, con=con) )
 
-setMethod("TSlabel",   signature(x="character", con="PostgreSQLConnection"),
+setMethod("TSlabel",   signature(x="character", con="TSPostgreSQLConnection"),
    definition= function(x, con=getOption("TSconnection"), ...)
         TSdbi:::TSlabelSQL(x=x, con=con) )
 
-setMethod("TSdelete", signature(serIDs="character", con="PostgreSQLConnection"),
+setMethod("TSdelete", signature(serIDs="character", con="TSPostgreSQLConnection"),
    definition= function(serIDs, con=getOption("TSconnection"),  
    vintage=getOption("TSvintage"), panel=getOption("TSpanel"), ...)
        TSdbi:::TSdeleteSQL(serIDs=serIDs, con=con, vintage=vintage, panel=panel) )
